@@ -173,6 +173,12 @@ class SerializationSchema(object):
         # current default is to return the input; may change
         return type_name, None
 
+    def handler_for(self, type_name):
+        for handler in self.attribute_handlers:
+            handler_obj = handler.from_type_string(type_name)
+            if handler_obj is not None:
+                return handler_obj
+
     def register_info(self, class_info_list, schema=None):
         schema = tools.none_to_default(schema, {})
         self.schema.update(schema)
